@@ -17,7 +17,6 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id$
  */
 
 #include "config.h"
@@ -56,45 +55,25 @@ ensure_auto_scroller (EphyWindow *window)
 	return scroller;
 }
 
-#if 0
 static gboolean
-dom_mouse_down_cb (EphyEmbed *embed,
-		   EphyEmbedEvent *event,
-		   EphyWindow *window)
-{
-	EphyAutoScroller *scroller;
-	EphyEmbedEventContext context;
-	guint button, x, y;
-
-	button = ephy_embed_event_get_button (event);
-	context = ephy_embed_event_get_context (event);
-
-	if (button != 2 || (context & EPHY_EMBED_CONTEXT_INPUT) ||
-            (context & EPHY_EMBED_CONTEXT_LINK))
-	{
-		return FALSE;
-	}
-
-	scroller = ensure_auto_scroller (window);
-	g_return_val_if_fail (scroller != NULL, FALSE);
-
-	ephy_embed_event_get_coords (event, &x, &y);
-	ephy_auto_scroller_start (scroller, embed, x, y);
-
-	return TRUE;
-}
-#endif
-
-static gboolean
-button_press_cb (GtkWidget *widget,
+dom_mouse_down_cb (EphyWebView *view,
 		   GdkEventButton *event,
 		   EphyWindow *window)
 {
 	EphyAutoScroller *scroller;
-	EphyEmbed *embed = (EphyEmbed*) gtk_widget_get_parent (gtk_widget_get_parent (widget));
+	guint context;
+	guint button;
+        WebKitHitTestResult *hit_test;
 
-	// FIXME: This will swallow middle clicks on inputs and links.
-	if (event->button != 2)
+	button = event->button;
+	hit_test = webkit_web_view_get_hit_test_result (WEBKIT_WEB_VIEW (view), event);
+	g_object_get (hit_test, "context", &context, NULL);
+	g_object_unref (hit_test);
+
+	if (button != 2 ||
+	    event->type != GDK_BUTTON_PRESS ||
+	    (context & WEBKIT_HIT_TEST_RESULT_CONTEXT_EDITABLE) ||
+	    (context & WEBKIT_HIT_TEST_RESULT_CONTEXT_LINK))
 	{
 		return FALSE;
 	}
@@ -102,16 +81,18 @@ button_press_cb (GtkWidget *widget,
 	scroller = ensure_auto_scroller (window);
 	g_return_val_if_fail (scroller != NULL, FALSE);
 
-	ephy_auto_scroller_start (scroller, embed, event->x_root, event->y_root);
+	ephy_auto_scroller_start (scroller,
+				  EPHY_GET_EMBED_FROM_EPHY_WEB_VIEW (view),
+				  event->x_root, event->y_root);
 
 	return TRUE;
 }
 
 static void
 impl_detach_window (EphyExtension *ext,
-                    EphyWindow *window)
+		    EphyWindow *window)
 {
-        g_object_set_data (G_OBJECT (window), WINDOW_DATA_KEY, NULL);
+	g_object_set_data (G_OBJECT (window), WINDOW_DATA_KEY, NULL);
 }
 
 static void
@@ -119,19 +100,14 @@ impl_attach_tab (EphyExtension *ext,
 		 EphyWindow *window,
 		 EphyEmbed *embed)
 {
-	GtkWidget* web_view;
+	WebKitWebView* web_view;
 	LOG ("impl_attach_tab");
 
 	g_return_if_fail (embed != NULL);
 
-#if 0
-	g_signal_connect_object (embed, "ge-dom-mouse-down",
-                                 G_CALLBACK (dom_mouse_down_cb), window, 0);
-#endif
-
-	web_view = gtk_bin_get_child (GTK_BIN (gtk_bin_get_child (GTK_BIN (embed))));
-	g_signal_connect_object (web_view, "button_press_event",
-                                 G_CALLBACK (button_press_cb), window, 0);
+	web_view = EPHY_GET_WEBKIT_WEB_VIEW_FROM_EMBED (embed);
+	g_signal_connect_object (web_view, "button-press-event",
+				 G_CALLBACK (dom_mouse_down_cb), window, 0);
 }
 
 static void
@@ -139,19 +115,14 @@ impl_detach_tab (EphyExtension *ext,
 		 EphyWindow *window,
 		 EphyEmbed *embed)
 {
-	GtkWidget *web_view;
+	WebKitWebView *web_view;
 	LOG ("impl_detach_tab");
 
 	g_return_if_fail (embed != NULL);
 
-#if 0
+	web_view = EPHY_GET_WEBKIT_WEB_VIEW_FROM_EMBED (embed);
 	g_signal_handlers_disconnect_by_func
-		(embed, G_CALLBACK (dom_mouse_down_cb), window);
-#endif
-
-	web_view = gtk_bin_get_child (GTK_BIN (gtk_bin_get_child (GTK_BIN (embed))));
-	g_signal_handlers_disconnect_by_func
-		(web_view, G_CALLBACK (button_press_cb), window);
+		(web_view, G_CALLBACK (dom_mouse_down_cb), window);
 }
 
 static void
