@@ -54,6 +54,8 @@ struct _RssUIPrivate
 	DBusGProxy *proxy;
 	/* A boolean flag indicating a dbus error */
 	gboolean dbus_error;
+	/* Extension reference to unset the dialog when it's unrefed */
+	EphyRssExtension *extension;
 };
 
 enum
@@ -61,6 +63,7 @@ enum
 	PROP_WINDOW,
 	PROP_LIST,
 	PROP_EMBED,
+	PROP_EXTENSION
 };
 
 enum
@@ -167,8 +170,9 @@ rss_ui_subscribe_selected (GtkTreeModel *model,
 static void
 rss_ui_response_cb (GtkWidget *widget,
 		    int response,
-		    RssUI *dialog)
+		    EphyRssExtension *extension)
 {
+	RssUI *dialog = ephy_rss_extension_get_dialog (extension);
 	RssUIPrivate *priv = dialog->priv;
 
 	if (response == GTK_RESPONSE_OK)
@@ -185,6 +189,7 @@ rss_ui_response_cb (GtkWidget *widget,
 	}
 
 	g_object_unref (dialog);
+	ephy_rss_extension_set_dialog (extension, NULL);
 }
 
 static FeedType
@@ -313,10 +318,6 @@ rss_ui_treeview_button_pressed_cb (GtkTreeView *treeview,
 				   GdkEventButton *event,
 				   RssUI *dialog)
 {
-	RssUIPrivate *priv = dialog->priv;
-	GtkTreeModel *model = GTK_TREE_MODEL (priv->store);
-	GtkTreeSelection *selection;
-	GtkTreeIter iter;
 	GtkTreePath *path = NULL;
 	GtkMenu *menu;
 
@@ -324,9 +325,7 @@ rss_ui_treeview_button_pressed_cb (GtkTreeView *treeview,
 
 	/* right-click? */
 	if (event->button != 3)
-	{
 		return FALSE;
-	}
 
 	/* Get tree path for row that was clicked */
 	if (!gtk_tree_view_get_path_at_pos (treeview,
@@ -336,27 +335,12 @@ rss_ui_treeview_button_pressed_cb (GtkTreeView *treeview,
 		return FALSE;
 	}
 
-	if (!gtk_tree_model_get_iter (model, &iter, path))
-	{
-		gtk_tree_path_free(path);
-		return FALSE;
-	}
-
-	/* Select the row the user clicked on */
-	selection = gtk_tree_view_get_selection (treeview);
-	if (gtk_tree_selection_count_selected_rows (selection) == 1)
-	{
-		gtk_tree_selection_unselect_all (selection);
-		gtk_tree_selection_select_path (selection, path);
-		gtk_tree_path_free (path);
-	}
-
 	/* now popup the menu */
 	menu = rss_ui_build_context_menu (dialog);
 	gtk_menu_popup (menu, NULL, NULL, NULL, NULL,
 			event->button, event->time);
 
-	return TRUE;
+	return FALSE;
 }
 
 /* Set dnd cursor to the default dnd Gtk one and not the GtktreeView one */
@@ -384,7 +368,7 @@ rss_ui_drag_data_get_cb (GtkWidget *widget,
 	if (feed == NULL || feed->address == NULL) return;
 
 	gtk_selection_data_set (selection_data,
-			        selection_data->target,
+			        gtk_selection_data_get_target (selection_data),
 			        8,
 			        (const guchar*) feed->address,
 			        strlen (feed->address));
@@ -474,7 +458,8 @@ rss_ui_populate_store (RssUI *dialog)
 	/* We start populating the list, and try to select as much as possible
 	 * avoiding duplicate feeds
 	 */
-	location = ephy_embed_get_location (priv->embed, TRUE);
+	location = ephy_web_view_get_location
+			(ephy_embed_get_web_view (priv->embed), TRUE);
 	decision.hostname = g_strdup (ephy_string_get_host_name (location));
 
 	/* Fill the store, and select the appropriate feeds */
@@ -502,7 +487,7 @@ rss_ui_init (RssUI *dialog)
 		LOG ("No connection to dbus:%s", error->message);
 		g_error_free (error);
 		return;
-    }
+	}
 
 	dialog->priv->proxy = dbus_g_proxy_new_for_name (connection,
                                      RSS_DBUS_SERVICE,
@@ -521,6 +506,7 @@ rss_ui_constructor (GType type,
 	EphyDialog *edialog;
 	GtkCellRenderer *renderer;
 	GtkTreeSelection *selection;
+	EphyRssExtension *extension;
 
 	object = parent_class->constructor (type, n_construct_properties,
 					    construct_params);
@@ -531,7 +517,7 @@ rss_ui_constructor (GType type,
 
 	ephy_dialog_construct (EPHY_DIALOG (edialog),
 			       properties,
-			       SHARE_DIR "/glade/rss-ui.glade",
+			       SHARE_DIR "/ui/rss-ui.ui",
 			       "rss_ui",
 			       GETTEXT_PACKAGE);
 
@@ -543,8 +529,11 @@ rss_ui_constructor (GType type,
 				  properties[PROP_CLOSE].id, &priv->close,
 				  NULL);
 
+	g_object_get (object,
+		      "extension", &extension,
+		      NULL);
 	g_signal_connect (priv->dialog, "response",
-			  G_CALLBACK (rss_ui_response_cb), dialog);
+			  G_CALLBACK (rss_ui_response_cb), extension);
 
 	priv->store = gtk_list_store_new (N_COLUMNS,
 					  RSS_TYPE_NEWSFEED,
@@ -622,8 +611,14 @@ rss_ui_get_property (GObject *object,
 				GValue *value,
 				GParamSpec *pspec)
 {
-	/* no readable properties */
-	g_return_if_reached ();
+	RssUI *dialog = RSS_UI (object);
+
+	switch (prop_id)
+	{
+		case PROP_EXTENSION:
+			g_value_set_object (value, dialog->priv->extension);
+			break;
+	}
 }
 
 static void
@@ -642,6 +637,9 @@ rss_ui_set_property (GObject *object,
 		case PROP_EMBED:
 			dialog->priv->embed = g_value_get_object (value);
 			break;
+		case PROP_EXTENSION:
+			dialog->priv->extension = g_value_get_object (value);
+			break;
 	}
 }
 
@@ -677,6 +675,17 @@ rss_ui_class_init (RssUIClass *klass)
 				      G_PARAM_WRITABLE |
 				      G_PARAM_CONSTRUCT_ONLY));
 
+	g_object_class_install_property
+		(object_class,
+		 PROP_EXTENSION,
+		 g_param_spec_object ("extension",
+				      "Extension",
+				      "Extension",
+				      EPHY_TYPE_RSS_EXTENSION,
+				      G_PARAM_READABLE |
+				      G_PARAM_WRITABLE |
+				      G_PARAM_CONSTRUCT_ONLY));
+
 	g_type_class_add_private (object_class, sizeof (RssUIPrivate));
 }
 
@@ -712,10 +721,12 @@ rss_ui_register_type (GTypeModule *module)
 
 RssUI *
 rss_ui_new (FeedList *list,
-	    EphyEmbed *embed)
+	    EphyEmbed *embed,
+	    EphyRssExtension *extension)
 {
 	return g_object_new (TYPE_RSS_UI,
 			     "list",  list,
 			     "embed", embed,
+			     "extension", extension,
 			     NULL);
 }
