@@ -25,19 +25,13 @@
 
 #include "ephy-css-menu.h"
 
-#include <epiphany/ephy-window.h>
-#include <epiphany/ephy-embed.h>
-#include <epiphany/ephy-embed-container.h>
+#include <epiphany/epiphany.h>
 
 #include "ephy-debug.h"
 
 #include "mozilla/mozilla-helpers.h"
 
-#include <gtk/gtkuimanager.h>
-#include <gtk/gtkactiongroup.h>
-#include <gtk/gtkradioaction.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkmenuitem.h>
+#include <gtk/gtk.h>
 
 #include <glib/gi18n-lib.h>
 
@@ -364,7 +358,7 @@ ephy_css_menu_set_window (EphyCSSMenu *menu, EphyWindow *window)
 	g_signal_connect (window, "notify::active-child",
 			  G_CALLBACK (sync_active_tab_cb), menu);
 
-	if (GTK_WIDGET_REALIZED (window))
+	if (gtk_widget_get_realized (GTK_WIDGET (window)))
 	{
 		embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
 		ephy_css_menu_set_embed (menu, embed);
