@@ -19,7 +19,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-select-stylesheet-extension.c 1636 2007-11-04 01:56:43Z cyrilbois $
+ *  $Id$
  */
 
 #include "config.h"
@@ -28,8 +28,7 @@
 #include "ephy-css-menu.h"
 #include "ephy-debug.h"
 
-#include <epiphany/ephy-extension.h>
-#include <epiphany/ephy-window.h>
+#include <epiphany/epiphany.h>
 
 #define WINDOW_DATA_KEY	"EphyCSSMenuExtensionWindowData"
 #define CSS_MENU_KEY	"EphyCSSMenu"
